//
//  View.m
//  Plot
//
//  Created by NYU User on 12/8/11.
//  Copyright (c) 2011 __MyCompanyName__. All rights reserved.
//

#import "View.h"
#import "ViewController.h"

@implementation View

- (id) initWithFrame: (CGRect) frame viewController: (ViewController *) c
{
	self = [super initWithFrame: frame];
	if (self) {
		// Initialization code
		viewController = c;
		CGSize s = self.bounds.size;

		pickerViews = [NSArray arrayWithObjects:
			[[UIPickerView alloc] initWithFrame: CGRectZero],
			[[UIPickerView alloc] initWithFrame: CGRectZero],
			[[UIPickerView alloc] initWithFrame: CGRectZero],
			nil
		];

		int i = 0;
		for (UIPickerView *pickerView in pickerViews) {
			CGSize size = [pickerView sizeThatFits: CGSizeZero];
			pickerView.showsSelectionIndicator = YES;
			pickerView.delegate = self;
			pickerView.dataSource = self;
			CGFloat scale = s.height / (pickerViews.count * size.height);

			pickerView.frame = CGRectMake(
				s.width * (1 - 1 / scale) / 2,
				(scale - 1) * size.height / 2 + i * s.height / pickerViews.count,
				s.width / scale,
				size.height
			);

			//Must set .transform after .frame.
			pickerView.transform = CGAffineTransformMakeScale(scale, scale);
			[self addSubview: pickerView];
			++i;
		}
	}
	return self;
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void) drawRect: (CGRect) rect
{
	// Drawing code
}
*/

#pragma mark -
#pragma mark methods of protocol UIPickerViewDataSource

- (NSInteger) numberOfComponentsInPickerView: (UIPickerView *) pickerView
{
	NSUInteger i = [pickerViews indexOfObject: pickerView];
	return [viewController numberOfComponentsInPickerView: i];
}


- (NSInteger) pickerView: (UIPickerView *) pickerView numberOfRowsInComponent: (NSInteger) component
{
	NSUInteger i = [pickerViews indexOfObject: pickerView];
	return [viewController pickerView: i numberOfRowsInComponent: component];
}

#pragma mark -
#pragma mark methods of protocol UIPickerViewDelegate

- (NSString *) pickerView: (UIPickerView *) pickerView
	titleForRow: (NSInteger) row forComponent: (NSInteger) component {

	NSUInteger i = [pickerViews indexOfObject: pickerView];
	return [viewController pickerView: i titleForRow: row forComponent: component];
}


- (void) pickerView: (UIPickerView *) pickerView
	didSelectRow: (NSInteger) row inComponent: (NSInteger) component {

	NSUInteger i = [pickerViews indexOfObject: pickerView];
	[viewController pickerView: i didSelectRow: row inComponent: component];
}

- (void) pickerView: (NSUInteger) pickerView
	selectRow: (NSInteger) row
	inComponent: (NSInteger) component
	animated: (BOOL) animated
{
	NSLog(@"View row %u", row);
	[[pickerViews objectAtIndex: pickerView] selectRow: row inComponent: component animated: animated];
}

@end
